==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translation>Перезаписать файл?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Файл с именем &apos;%1&apos; уже существует. Заменить его?</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>Не рекомендуемая версия формата файла</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Используется не рекомендованная версия формата файла: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Все чёрные объекты и слои будут сохранены как белые.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Все пользовательские цвета будут &apos;округляться&apos; до ближайшего фиксированного цвета.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>Продолжить?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>Сохраняется...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Запись версии формата файла &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Чёрные объекты и слои сохранены как белые.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Пользовательские цвета &apos;округлены&apos; до ближайшего фиксированного цвета.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Не удалось сохранить файл %1.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saved drawing:</source>
        <translation>Чертёж сохранен:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translation>Перезаписать файл?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Файл с именем &apos;%1&apos; уже существует. Заменить его?</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>Не рекомендуемая версия формата файла</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Используется не рекомендованная версия формата файла: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Все чёрные объекты и слои будут сохранены как белые.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Все пользовательские цвета будут &apos;округляться&apos; до ближайшего фиксированного цвета.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>Продолжить?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>Сохраняется...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Запись версии формата файла &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Чёрные объекты и слои сохранены как белые.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Пользовательские цвета &apos;округлены&apos; до ближайшего фиксированного цвета.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Не удалось сохранить файл %1.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Saved drawing:</source>
        <translation>Чертёж сохранен:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
</context>
</TS>
